/******************************************************************************
This is the stata do file for a research skills seminar on stata programming
Data file required is data1.dta. File can be found at www.jwbbos.com -> Code
******************************************************************************/

/******************************************************************************
First we set some standard settings
******************************************************************************/

clear
set memory 200m
*cd "\\.psf\Projects\USE\ResearchSkills\stata1\" /* Fill in your own file path */
cd "/Projects\USE/ResearchSkills/stata1" 
set more off
set scheme sj, permanently
cap log close
log using researchskills_log, replace

/******************************************************************************
Now we load the data and create some descriptive statistics
******************************************************************************/

use stata1, clear

sum y x1 x2 x3

/******************************************************************************
Run a simple regression
******************************************************************************/

reg y x1 x2 x3

/* Select the table, rightclick on it, and you can choose copy table. Now you
can copy the table into excel...*/ 

/******************************************************************************
Combining regression output and using outreg
******************************************************************************/

reg y x1
est store A, title(simple model)
reg y x1 x2 x3
est store B, title(not so simple model)

/* Getting the results to look nice. Type: help est_table */

estimates table A B, b(%9.3f) t(%9.3f) label varwidth(30) title("A cool table")
outreg using ABtable, title("A cool table") replace

/******************************************************************************
Another look at summary statistics ... and scalars
******************************************************************************/

sum y
return list /* Hint: type "help return" for an overview...*/

/* Now let us create a variable that indicates whether an observation is 
more than 2 standard deviations away from the mean */

gen ci=0
label var ci "confidence interval"
replace ci=1 if y>(r(mean)+2*(r(sd)))
replace ci=1 if y<(r(mean)-2*(r(sd)))
tab ci

/******************************************************************************
Fancy regression output (more difficult, but highly customizable)

Let's say that we have ten groups of 200 observations each. We want to regress
y on x1 and x2 and x3, and we would like to have a table with the coefficients
for x1 and x2 (x3 is a not so interesting control variable). 
******************************************************************************/
								
egen i=seq(), from(1) to(10) /* Generating 10 groups (in an ad hoc fashion */
gen i_string=i
tostring i_string, replace /* We make a string equivalent of variable i */
replace i_string="A" if i_string=="1"
replace i_string="B" if i_string=="2"
replace i_string="C" if i_string=="3"
replace i_string="D" if i_string=="4"
replace i_string="E" if i_string=="5"
replace i_string="F" if i_string=="6"
replace i_string="G" if i_string=="7"
replace i_string="H" if i_string=="8"
replace i_string="I" if i_string=="9"
replace i_string="J" if i_string=="10"

local individual "A B C D E F G H I J"

cap matrix drop all
cap matrix drop all1
cap matrix drop all2
matrix all = (0,0,0,0,0,0)
matrix colnames all = b1 se_b1 b2 se_b2 N Rsquared
foreach var of local individual {
	cap set more off, permanently
	reg y x1 x2 x3 if i_string=="`var'"
      quietly matrix a=e(b)
 	quietly matrix b=e(V)
	quietly matrix d=e(N)
	quietly scalar N=d[1,1]
	quietly scalar Rsquared=e(r2_a)
	quietly scalar b1=a[1,1]
	quietly scalar se_b1=(b[1,1])^.5
	quietly scalar b2=a[1,2]
	quietly scalar se_b2=(b[2,2])^.5
	matrix all1=(b1,se_b1,b2,se_b2,N,Rsquared)
	matrix all2=all
	matrix all=all2\all1
	}

matrix temp=all[2..11,1..6]
collapse i, by(i_string)
svmat temp, names(col)
drop i

/* Now we have our table. One more thing though: we'll replace the standard 
errors with asterisks to indicate significance levels */

local variables "b1 b2"
foreach var of local variables {
	gen t_`var'=""
	replace t_`var'="*" if (abs(`var')/(se_`var')>=1.64 & abs(`var')/(se_`var')<1.96)
	replace t_`var'="**" if (abs(`var')/(se_`var')>=1.96 & abs(`var')/(se_`var')<2.58)
	replace t_`var'="***" if (abs(`var')/(se_`var')>=2.58)
	move t_`var' se_`var'
	drop se_`var'
	}
outsheet using "table1.csv", comma replace /* This file can easily be opened in excel */

/******************************************************************************
Conditional marginal effects, based on:
Thomas Brambor , William Roberts Clark , and Matt Golder
Understanding Interaction Models: Improving Empirical Analyses 
Political Analysis Advance Access published on May 23, 2005, DOI 10.1093/pan/mpi014.

Web page at http://homepages.nyu.edu/~mrg217/interaction.html
******************************************************************************/

use stata1, clear

gen x1x2=x1*x2
reg y x1 x2 x1x2 x3

matrix b=e(b)
matrix V=e(V)
scalar b1=b[1,1]
scalar b2=b[1,2]
scalar b3=b[1,3]
scalar varb1=V[1,1]
scalar varb2=V[2,2]
scalar varb3=V[3,3]
scalar covb1b2=V[1,2]
scalar covb1b3=V[1,3]
scalar covb2b3=V[2,3]
scalar list b1 b2 b3 varb1 varb2 varb3 covb1b2 covb1b3 covb2b3
gen conb=b1+b3*x2
gen conse=sqrt(varb1+varb3*(x2^2)+2*covb1b3*x2)
gen a=1.96*conse
gen upper=conb+a
gen lower=conb-a

twoway ///
(line conb x2, fxsize(75) lpattern(solid) lwidth(medium))  ///
(line upper x2, lpattern(shortdash) lwidth(thin))  ///
(line lower x2, lpattern(shortdash) lwidth(thin)  ///
yscale(noline) xscale(noline) xtitle("") ytitle("") ///
title("Marginal effect", size(*.8)) legend(off) ///
scheme(sj) graphregion(fcolor(white))) 
graph export conditionalmarginaleffect.png, replace

/******************************************************************************
This is the stata file for generating theoretical graphs for the industry 
frontier paper. It requires no data file. Jaap Bos, j.bos@econ.uu.nl
******************************************************************************/

clear

range number 1 1 1

input y1 x1 y2 x2
1 1 1 1

capture drop Ox Oy Ax Ay Bx By Cx Cy Dx Dy

gen Ax = 15
gen Ay = 18.75
gen Bx = 15
gen By = 16
gen Cx = 15
gen Cy = 10
gen Dx = 15
gen Dy = 13.5

twoway (function y=2*x-0.05*x^2, range(0 20) lcolor(purple) lwidth(thick) graphregion(color(white)) ///
text(18 17 "frontier", placement(ne) size(*.9)) ///
ylabel(none) xlabel(none) ///
ytitle("output", justification(right) orientation(horizontal) placement(top) size(*.9) margin(medium)) ///
xtitle("input",justification(right) orientation(horizontal) placement(right) size(*.9) margin(medium))) ///
(dot Ay Ax, text(18.5 15.25 "i", placement(4)) mcolor(gs0) msymbol(o) ndots(0) msize(large)) ///
(dot By Bx, text(15.75 15.25 "ii", placement(4)) mcolor(gs0) msymbol(o) ndots(0) msize(large)) ///
(dot Cy Cx, text(9.75 15.25 "iii", placement(4)) mcolor(gs0) msymbol(o) ndots(0) msize(large)) ///
(function y=15, range(0 18.75) clpattern(dot) horizontal legend(off)) 
graph export graph_theory1.eps, replace

twoway (function y=2*x-0.05*x^2, range(0 20) lcolor(purple) lwidth(medthick) graphregion(color(white)) ///
text(18 16 "club A", placement(ne) size(*.9)) ///
ylabel(none) xlabel(none) ///
ytitle("output", justification(right) orientation(horizontal) placement(top) size(*.9) margin(medium)) ///
xtitle("input",justification(right) orientation(horizontal) placement(right) size(*.9) margin(medium))) ///
(function y=1.5*x-0.04*x^2, lwidth(medthick) range(0 20) lcolor(purple) graphregion(color(white)) ///
text(12 16 "club B", placement(ne) size(*.9))) ///
(dot Ay Ax, text(18.5 15.25 "i", placement(4)) mcolor(gs0) msymbol(o) ndots(0) msize(large)) ///
(dot By Bx, text(15.75 15.25 "ii", placement(4)) mcolor(gs0) msymbol(o) ndots(0) msize(large)) ///
(dot Dy Dx, text(13.5 15.25 "iv", placement(4)) mcolor(gs0) msymbol(o) ndots(0) msize(large)) ///
(dot Cy Cx, text(9.75 15.25 "iii", placement(4)) mcolor(gs0) msymbol(o) ndots(0) msize(large)) ///
(function y=15, range(0 18.75) clpattern(dot) horizontal legend(off)) 
graph export graph_theory2.eps, replace

